<?php

namespace App\Service;

use App\Entity\Snip;
use App\Git\CustomGit;
use App\Repository\SnipContentRepository;
use App\Service\SnipContent\SnipContentDB;
use App\Service\SnipContent\SnipContentGit;
use Symfony\Bundle\SecurityBundle\Security;

class SnipServiceFactory
{
    public function __construct(
        private readonly string                $snipBasePath,
        private readonly Security              $security,
        private readonly SnipContentRepository $snipContentRepository,
    )
    {
    }

    public function createGit(Snip $snip): SnipContentGit
    {
        $git = new CustomGit();
        $repoPath = sprintf('%s/%s', $this->snipBasePath, $snip->getId());
        if (!is_dir($repoPath)) {
            $repo = $git->init($repoPath);
            touch(sprintf('%s/.gitignore', $repoPath));
            $repo->addFile('.gitignore');
            $repo->commit('Initial commit');
        } else {
            $repo = $git->open($repoPath);
        }
        return new SnipContentGit($repo, $this->security->getUser());
    }

    public function createDB(Snip $snip): SnipContentDB
    {
        return new SnipContentDB($snip, $this->security->getUser(), $this->snipContentRepository);
    }
}